/* ======================================================================
Authors: Diemo Urbig, Werner Bönte
Reference: Bönte, W., Procher, V., & Urbig, D. (2018). Gender differences 
in selection into self-competition. Applied Economics Letters, 25(8), 539-543.
====================================================================== */
capture cd "C:\Users\Diemo\Dropbox\Competitiveness\CityArkaden-2014\"
clear all
use "public data"

capture log close _all
log using "AEL-$S_DATE" , replace text name(logfile)

ttest piec_perf  , by(male)

prtest self_comp, by(male)
prtest othr_comp, by(male)
prtest self_comp if self_strength>1, by(male)
prtest othr_comp if othr_strength>1, by(male)

bys male: pwcorr othr_comp self_comp, sig

ttest riskgen, by(male)
ttest riskinv, by(male)

logit  self_comp i.male 
margin , dydx(*) post
outreg2 using "tab12", replace word dec(3) bdec(3) sdec(3)  symbol(***,**,*,+) alpha(0.001,0.01,0.05,0.1) aster(coef) eq(auto) 
logit self_comp i.male i.agec2 i.parententre i.exp_othr_second piec_perf
margin , dydx(*) post
outreg2 using "tab12", append word dec(3) bdec(3) sdec(3)  symbol(***,**,*,+) alpha(0.001,0.01,0.05,0.1) aster(coef) eq(auto) 
logit self_comp i.male  riskgen i.agec2 i.parententre i.exp_othr_second piec_perf
margin , dydx(*) post
outreg2 using "tab12", append word dec(3) bdec(3) sdec(3)  symbol(***,**,*,+) alpha(0.001,0.01,0.05,0.1) aster(coef) eq(auto) 
logit self_comp i.male  riskinv i.agec2 i.parententre i.exp_othr_second piec_perf
margin , dydx(*) post
outreg2 using "tab12", append word dec(3) bdec(3) sdec(3)  symbol(***,**,*,+) alpha(0.001,0.01,0.05,0.1) aster(coef) eq(auto) 
logit self_comp i.male  riskgen riskinv i.agec2 i.parententre i.exp_othr_second piec_perf
margin , dydx(*) post
outreg2 using "tab12", append word dec(3) bdec(3) sdec(3)  symbol(***,**,*,+) alpha(0.001,0.01,0.05,0.1) aster(coef) eq(auto) 


// Decomposition of the gender effect 
xi: fairlie self_comp  riskgen riskinv i.agec2 i.parententre exp_othr_second piec_perf, by(male)
xi: fairlie self_comp  othr_comp piec_perf i.agec2 i.parententre exp_othr_second , by(male)
xi: fairlie self_comp  riskgen riskinv i.agec2 i.parententre exp_othr_second piec_perf othr_comp, by(male)

tab male
tab agec2
tab school
tab university
sum occ_empl occ_publ occ_entr occ_educ occ_othr occ_na

tab self_comp othr_comp, chi2 
prtest self_comp, by(othr_comp)

pwcorr self_comp othr_comp, sig
spearman self_comp othr_comp
tetrachoric self_comp othr_comp

bys male: tab self_comp
bys male: tab self_comp if othr_comp==0
bys male: tab self_comp if othr_comp==1

prtest self_comp, by(male)
prtest self_comp if othr_comp==0, by(male)
prtest self_comp if othr_comp==1, by(male)

gen C = 2*self_comp + othr_comp
tab C if male==1 
tab C if male==0
tab C, gen(c)
prtest c1, by(male)
prtest c2, by(male)
prtest c3, by(male)
prtest c4, by(male)

prtest self_comp, by(male)
tab self_comp male, chi2 ex gamma lrchi2 taub V

gen D = self_comp!=othr_comp
prtest D ,by(male)
tab D male, chi2 ex gamma lrchi2 taub V

bys male: tab agec2
tab agec2, gen(agec2i)
tab agec2 male, chi2 
tab agec2i1 male, chi2
tab agec2i2 male, chi2
tab agec2i3 male, chi2
tab agec2i4 male, chi2
tab agec2i5 male, chi2

bys male: tab school 
tab school , gen(schooli) 
tab school male, chi2
tab schooli1 male, chi2
tab schooli2 male, chi2
tab schooli3 male, chi2
tab schooli4 male, chi2
tab schooli5 male, chi2

prtest university, by(male)
tab university male, chi2

prtest jobtraining, by(male)
tab jobtraining male, chi2

tab occ2
bys male: tab occ2
tab occ2 male, chi2
tab occ_empl male, chi2
tab occ_publ male, chi2
tab occ_entr male, chi2
tab occ_educ male, chi2
tab occ_othr male, chi2
tab occ_na male, chi2

tab parententre
bys male: tab parententre
tab parententre male, chi2

gen noentre = (parententre==4)
tab noentre male, chi2
tab onlymoentre male, chi2
tab onlyfaentre male, chi2
tab mofaentre male, chi2


bys male: sum othr_comp
tab othr_comp male, chi2 exact
prtest othr_comp, by(male)

log close _all